@@ -241,8 +241,6 @@ public class ReferenceExtractor extends ClassVisitor {
 
 		/**
 		 * Constructor
-		 *
-		 * @param mv
 		 */
 		public ClassFileMethodVisitor(MethodVisitor mv, String name, int argumentcount) {
 			super(Util.LATEST_OPCODES_ASM, mv);
@@ -417,8 +415,7 @@ public class ReferenceExtractor extends ClassVisitor {
 		@Override
 		public void visitInvokeDynamicInsn(String name, String desc, Handle bsm, Object... bsmArgs) {
 			for (Object arg : bsmArgs) {
-				if (arg instanceof Handle) {
-					Handle handle = (Handle) arg;
+				if (arg instanceof Handle handle) {
 					Type declaringType = Type.getObjectType(handle.getOwner());
 					Reference reference = ReferenceExtractor.this.addMethodReference(declaringType, handle.getName(), handle.getDesc(), IReference.REF_VIRTUALMETHOD, 0);
 					if (reference != null) {
@@ -564,14 +561,12 @@ public class ReferenceExtractor extends ClassVisitor {
 
 		@Override
 		public void visitLdcInsn(Object cst) {
-			if (cst instanceof Type) {
-				Type type = (Type) cst;
+			if (cst instanceof Type type) {
 				Reference reference = ReferenceExtractor.this.addTypeReference(type, IReference.REF_CONSTANTPOOL);
 				if (reference != null) {
 					this.linePositionTracker.addLocation(reference);
 				}
-			} else if (cst instanceof String) {
-				String str = (String) cst;
+			} else if (cst instanceof String str) {
 				this.stringLiteral = (Util.EMPTY_STRING.equals(str) ? null : str);
 			}
 		}
@@ -632,8 +627,6 @@ public class ReferenceExtractor extends ClassVisitor {
 
 		/**
 		 * Add a field to be tracked
-		 *
-		 * @param field
 		 */
 		public void addField(Reference ref) {
 			if (ref != null) {
@@ -643,8 +636,6 @@ public class ReferenceExtractor extends ClassVisitor {
 
 		/**
 		 * Add an accessor to be tracked
-		 *
-		 * @param accessor
 		 */
 		public void addAccessor(Reference ref) {
 			if (ref != null) {
@@ -710,7 +701,7 @@ public class ReferenceExtractor extends ClassVisitor {
 
 		public void computeLineNumbers() {
 
-			if (this.lineInfos.size() < 1 || this.labelsAndLocations.size() < 1) {
+			if (this.lineInfos.isEmpty() || this.labelsAndLocations.isEmpty()) {
 				// nothing to do
 				return;
 			}
@@ -730,11 +721,11 @@ public class ReferenceExtractor extends ClassVisitor {
 			// Iterate over List of Labels and SourceLocations.
 			List<Object> computedEntries = new ArrayList<>();
 			for (Object current : this.labelsAndLocations) {
-				if (current instanceof Label) {
+				if (current instanceof Label label) {
 					// label
 					Integer lineValue = this.lineMap.get(current);
 					if (lineValue != null) {
-						computedEntries.add(new LineInfo(lineValue.intValue(), (Label) current));
+						computedEntries.add(new LineInfo(lineValue.intValue(), label));
 					} else {
 						computedEntries.add(current);
 					}
@@ -762,15 +753,13 @@ public class ReferenceExtractor extends ClassVisitor {
 							remainingCatchLabelInfos = remaingEntriesTemp;
 						}
 					}
-				} else if (current instanceof Reference) {
-					Reference ref = (Reference) current;
+				} else if (current instanceof Reference ref) {
 					if (ref.getLineNumber() == -1) {
 						ref.setLineNumber(currentLineNumber);
 					} else {
 						currentLineNumber = ref.getLineNumber();
 					}
-				} else if (current instanceof LineInfo) {
-					LineInfo lineInfo = (LineInfo) current;
+				} else if (current instanceof LineInfo lineInfo) {
 					currentLineNumber = lineInfo.line;
 				}
 			}
@@ -810,8 +799,7 @@ public class ReferenceExtractor extends ClassVisitor {
 
 		@Override
 		public boolean equals(Object obj) {
-			if (obj instanceof LineInfo) {
-				LineInfo lineInfo2 = (LineInfo) obj;
+			if (obj instanceof LineInfo lineInfo2) {
 				return this.line == lineInfo2.line && this.label.equals(lineInfo2.label);
 			}
 			return super.equals(obj);
@@ -841,8 +829,7 @@ public class ReferenceExtractor extends ClassVisitor {
 
 		@Override
 		public boolean equals(Object obj) {
-			if (obj instanceof LocalLineNumberMarker) {
-				LocalLineNumberMarker marker = (LocalLineNumberMarker) obj;
+			if (obj instanceof LocalLineNumberMarker marker) {
 				return this.lineNumber == marker.lineNumber && this.varIndex == marker.varIndex;
 			}
 			return false;
@@ -893,7 +880,7 @@ public class ReferenceExtractor extends ClassVisitor {
 	 * Whether to extract references to elements within the classfile being
 	 * scanned.
 	 */
-	private boolean fIncludeLocalRefs = false;
+	private final boolean fIncludeLocalRefs = false;
 
 	/**
 	 * Bit mask of {@link ReferenceModifiers} to extract.
@@ -928,7 +915,7 @@ public class ReferenceExtractor extends ClassVisitor {
 	 * Current field being visited, or <code>null</code> (when not within a
 	 * field).
 	 */
-	private ClassFileSignatureVisitor signaturevisitor = new ClassFileSignatureVisitor();
+	private final ClassFileSignatureVisitor signaturevisitor = new ClassFileSignatureVisitor();
 	static int TYPE = 0, FIELD = 1, METHOD = 2;
 
 	/**
@@ -937,7 +924,7 @@ public class ReferenceExtractor extends ClassVisitor {
 	 *
 	 * @since 1.0.600
 	 */
-	private ClassFileFieldVisitor fieldvisitor = new ClassFileFieldVisitor();
+	private final ClassFileFieldVisitor fieldvisitor = new ClassFileFieldVisitor();
 
 	/**
 	 * Constructor
@@ -958,11 +945,6 @@ public class ReferenceExtractor extends ClassVisitor {
 
 	/**
 	 * Constructor
-	 *
-	 * @param type
-	 * @param collector
-	 * @param referenceKinds
-	 * @param tracker
 	 */
 	protected ReferenceExtractor(IApiType type, Set<Reference> collector, int referenceKinds, FieldTracker tracker) {
 		super(Util.LATEST_OPCODES_ASM, new ClassNode());
@@ -991,7 +973,6 @@ public class ReferenceExtractor extends ClassVisitor {
 	 * Returns whether to consider a reference to the specified type. Configured
 	 * by setting to include references within the same class file.
 	 *
-	 * @param owner
 	 * @return true if considered, false otherwise
 	 */
 	protected boolean consider(String owner) {
@@ -1035,9 +1016,6 @@ public class ReferenceExtractor extends ClassVisitor {
 	/**
 	 * Returns the full internal name (if available) from the given simple name.
 	 * The returned name has been modified to be '.' separated
-	 *
-	 * @param name
-	 * @return
 	 */
 	protected String processName(String name) {
 		String newname = name;
@@ -1054,7 +1032,6 @@ public class ReferenceExtractor extends ClassVisitor {
 	 * the type is a primitive type.
 	 *
 	 * @param type referenced type
-	 * @param linenumber line number where referenced
 	 * @param kind kind of reference
 	 * @return reference added, or <code>null</code> if none
 	 */
@@ -1072,7 +1049,6 @@ public class ReferenceExtractor extends ClassVisitor {
 	 *
 	 * @param declaringType type declaring the field being referenced
 	 * @param name of the field being referenced
-	 * @param linenumber line number where referenced
 	 * @param kind kind of reference
 	 * @return reference added, or <code>null</code> if none
 	 */
@@ -1092,7 +1068,6 @@ public class ReferenceExtractor extends ClassVisitor {
 	 *            lookup)
 	 * @param name of the method being referenced
 	 * @param signature signature of the method
-	 * @param linenumber line number where referenced
 	 * @param kind kind of reference
 	 * @param flags the flags for the reference
 	 * @return reference added, or <code>null</code> if none
@@ -1106,13 +1081,12 @@ public class ReferenceExtractor extends ClassVisitor {
 	}
 
 	/**
-	 * Adds a reference to the given target member from the given line number in
-	 * the class file being scanned. If the target member is contained in the
-	 * class file being scanned it is discarded based on the setting to include
-	 * local references.
+	 * Adds a reference to the given target member from the given line number in the
+	 * class file being scanned. If the target member is contained in the class file
+	 * being scanned it is discarded based on the setting to include local
+	 * references.
 	 *
-	 * @param target reference
-	 * @param reference added, or <code>null</code> if none
+	 * @param target reference added, or <code>null</code> if none
 	 */
 	protected Reference addReference(Reference target) {
 		if (this.consider(target)) {
@@ -1160,7 +1134,6 @@ public class ReferenceExtractor extends ClassVisitor {
 	 * the ASM framework If the description is an array, the underlying type of
 	 * the array is returned.
 	 *
-	 * @param desc
 	 * @return the {@link Type} of the description or <code>null</code>
 	 */
 	protected Type resolveType(String desc) {
@@ -1297,11 +1270,6 @@ public class ReferenceExtractor extends ClassVisitor {
 
 	/**
 	 * Processes the dependent inner class
-	 *
-	 * @param type
-	 * @param refkinds
-	 * @return
-	 * @throws CoreException
 	 */
 	private Set<Reference> processInnerClass(IApiType type, int refkinds) throws CoreException {
 		HashSet<Reference> refs = new HashSet<>();
@@ -1327,8 +1295,8 @@ public class ReferenceExtractor extends ClassVisitor {
 		if (fIsVisitMembers) {
 			IApiMember member = this.getMember();
 			IApiType owner = null;
-			if (member instanceof IApiType) {
-				owner = (IApiType) member;
+			if (member instanceof IApiType apiType) {
+				owner = apiType;
 			} else {
 				try {
 					owner = member.getEnclosingType();
@@ -1434,7 +1402,6 @@ public class ReferenceExtractor extends ClassVisitor {
 	 *            searched for a declaration
 	 * @return the IApiType containing the default method definition or
 	 *         <code>null</code>
-	 * @throws CoreException
 	 */
 	static IApiType getDefaultDefined(IApiType type, String name, String signature, boolean isOverride) throws CoreException {
 		if (type != null) {
@@ -1450,7 +1417,7 @@ public class ReferenceExtractor extends ClassVisitor {
 			if (superclass != null) {
 				return superclass;
 			}
-			IApiType ints[] = type.getSuperInterfaces();
+			IApiType[] ints = type.getSuperInterfaces();
 			for (IApiType j : ints) {
 				IApiType superint = getDefaultDefined(j, name, signature, false);
 				if (superint != null) {
